@@ -7,8 +7,8 @@ def cmd():
 
 
 @cmd.command()
-@click.option('--key', default=None, help="encrypt key string")
-@click.argument('fp', type=click.Path(exists=True))
+@click.argument('key', help="encrypt key string")
+@click.argument('fp', help="file to be encrypted")
 def encrypt(key, fp):
     print(f"{fp} with key {key}")
     encrypt_file(fp, key)
